summaryrefslogtreecommitdiff
path: root/include/modules.h
diff options
context:
space:
mode:
authorAttila Molnar <attilamolnar@hush.com>2014-02-14 12:00:06 +0100
committerAttila Molnar <attilamolnar@hush.com>2014-02-14 12:00:06 +0100
commit51b5f06c48b98a256eb56ea5f7e4d5d170555e84 (patch)
treeccc93b4b9fc7c273f7ddfb9c44b6ddc1dec2e91a /include/modules.h
parent3111038011b7414c5068563b2abe834267a368ad (diff)
Return a Membership* from get_first_visible_channel() in cmd_who and pass that to modules
Diffstat (limited to 'include/modules.h')
-rw-r--r--include/modules.h4
1 files changed, 2 insertions, 2 deletions
diff --git a/include/modules.h b/include/modules.h
index 2abed2935..7df6f4f3b 100644
--- a/include/modules.h
+++ b/include/modules.h
@@ -1053,10 +1053,10 @@ class CoreExport Module : public classbase, public usecountbase
* @param source The user running the /WHO query
* @param params The parameters to the /WHO query
* @param user The user that this line of the query is about
* @param chan The channel in this line, can be NULL
* @param line The raw line to send; modifiable, if empty no line will be returned.
*/
- virtual void OnSendWhoLine(User* source, const std::vector<std::string>& params, User* user, Channel* chan, std::string& line);
+ virtual void OnSendWhoLine(User* source, const std::vector<std::string>& params, User* user, Membership* memb, std::string& line);
/** Called whenever a local user's IP is set for the first time, or when a local user's IP changes due to
* a module like m_cgiirc changing it.
@@ -1053,10 +1053,10 @@ class CoreExport Module : public classbase, public usecountbase
* @param params The parameters to the /WHO query
* @param user The user that this line of the query is about
- * @param chan The channel in this line, can be NULL
+ * @param memb The member shown in this line, NULL if no channel is in this line
* @param line The raw line to send; modifiable, if empty no line will be returned.
*/